pub struct TraceRelation {
pub parent: AssociationStatus,
pub child: AssociationStatus,
}Expand description
Holds the parent/child relationship for a trace
Fields
parent: AssociationStatusIndex of the parent trace (e.g., RRC for a NAS message)
child: AssociationStatusIndex of the child trace (e.g., NAS for an RRC message with dedicated NAS)
Implementations
Sourceimpl TraceRelation
impl TraceRelation
Sourcepub fn has_parent(&self) -> bool
pub fn has_parent(&self) -> bool
Check if this trace has a parent
Sourcepub fn get_parent_index(&self) -> Option<usize>
pub fn get_parent_index(&self) -> Option<usize>
Get parent index if available
Sourcepub fn get_parent_indices(&self) -> Option<&Vec<usize>>
pub fn get_parent_indices(&self) -> Option<&Vec<usize>>
Get parent indices if available
Sourcepub fn get_child_index(&self) -> Option<usize>
pub fn get_child_index(&self) -> Option<usize>
Get child index if available
Sourcepub fn get_child_indices(&self) -> Option<&Vec<usize>>
pub fn get_child_indices(&self) -> Option<&Vec<usize>>
Get child indices if available
Sourcepub fn set_parent(&mut self, index: usize)
pub fn set_parent(&mut self, index: usize)
Set parent as found (replaces existing)
Sourcepub fn add_parent(&mut self, index: usize) -> bool
pub fn add_parent(&mut self, index: usize) -> bool
Add a parent index (appends to existing if Found)
Sourcepub fn add_child(&mut self, index: usize) -> bool
pub fn add_child(&mut self, index: usize) -> bool
Add a child index (appends to existing if Found)
Sourcepub fn set_parent_not_found(&mut self)
pub fn set_parent_not_found(&mut self)
Mark parent search as completed with no result
Sourcepub fn set_child_not_found(&mut self)
pub fn set_child_not_found(&mut self)
Mark child search as completed with no result
Sourcepub fn set_parent_not_applicable(&mut self)
pub fn set_parent_not_applicable(&mut self)
Mark parent as not applicable for this trace type
Sourcepub fn set_child_not_applicable(&mut self)
pub fn set_child_not_applicable(&mut self)
Mark child as not applicable for this trace type
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Reset the relation (mark as not computed) - useful when new traces arrive